@@ -8,8 +8,7 @@ jinja_env = Environment()
 
 
 def jinja_minify(jinja, settings: dict):
-    """Minify jinja main function. Does not minify, rather detects errors (lint)
-    """
+    """Minify jinja main function. Does not minify, rather detects errors (lint)"""
     try:
         jinja_env.parse(jinja)
     except Exception as e:
