@@ -12,9 +12,7 @@ try:
     have_sass = True
 except Exception:
     logger.warning("Could not import sass", exc_info=True)
-    logger.warning(
-        "NOTE: To install sass, please remember to use  use pip install libsass instead of pip install sass"
-    )
+    logger.warning("NOTE: To install sass, please remember to use  use pip install libsass instead of pip install sass")
 
 
 def sass_minify(css, settings: dict):
